@@ -14,9 +14,9 @@ $VERSION     = 0.05;
 ## shut strict up. Set $READSEQ_PATH to the full path
 ## to the readseq executable.
  
-## $OK = "Y"; 
-## $OK = "Y"; 
-my $READSEQ_PATH=undef;
+$OK = "Y"; 
+$OK = "Y"; 
+my $READSEQ_PATH= "/usr/bin/readseq";
 
 ############
 ############
