@@ -22,27 +22,13 @@
 #include "linesubs.h"
 #include "complexsequence.h"
 #include "complexevalset.h"
-#include "complexconsensi.h"
-#include "codon.h"
-#include "codonmapper.h"
 #include "alnconvert.h"
 #include "alnrange.h"
 #include "compmat.h"
-#include "codonmatrix.h"
 #include "dnamatrix.h"
 #include "protein.h"
-#include "genomic.h"
-#include "genomicdb.h"
-#include "cdna.h"
-#include "cdnadb.h"
 #include "dna.h"
 
-#include "embl.h"
-#include "genomicregion.h"
-#include "gene.h"
-#include "transcript.h"
-#include "translation.h"
-
 #include "btcanvas.h"
 #include "asciibtcanvas.h"
 
